@@ -97,7 +97,7 @@ class FileInfo:
     
     def __init__(self, path):
         self.path = path
-        self.size = os.gesize(path)
+        self.size = os.getsize(path)
         self.atime = os.getatime(path)
         self.ctime = os.getctime(path)
         self.mtime = os.getmtime(path)
